<?php
/*
 * @author Klaas Eikelboom  <klaas.eikelboom@civicoop.org>
 * @date 17-Jan-2022
 * @license  GPL-2.0-or-later
 */

namespace Drupal\cmrf_user_sync\Plugin\QueueWorker;

use Drupal\Core\Annotation\QueueWorker;
use Drupal\Core\Queue\QueueWorkerBase;

/**
 * Plugin implementation of the cmrf_user_sync_queue queueworker.
 *
 * @QueueWorker (
 *   id = "cmrf_user_sync_queue",
 *   title = @Translation("Synchronize users from CiviCRM Change Messages"),
 *   cron = {"time" = 30}
 * )
 */
class UserSyncQueue extends QueueWorkerBase {

  var $config;
  var $queue;
  var $core;
  var $userSyncManager;

  /**
   * UserSyncQueue constructor.
   */
  public function __construct() {
    $this->config=\Drupal::config('cmrf_user_sync.usersyncconfig');
    $this->queue = \Drupal::service('queue')->get('cmrf_user_sync_queue');
    $this->core = \Drupal::service('cmrf_core.core');
    $this->userSyncManager = \Drupal::service('plugin.manager.cmrf.user_sync');
  }

  /**
   * @return void
   */
  private function actionGet(){
    $connection = $this->config->get('connection');
    $messagedef = $this->config->get('messagedef');
    $email = $this->config->get('email');
    $name = $this->config->get('name');
    $contact_id = $this->config->get('contact_id');

    $call = $this->core->createCall($connection,'ChangeMessageApiQueue','get',['name'=>$messagedef]);
    $result = $this->core->executeCall($call);
    if($result['is_error']){
      \Drupal::logger('cmrf_user_sync')->error('Error using connection @connection with messsage definition @messagedef '.$result['message'],[
        '@connection' => $connection,
        '@messagedef' => $messagedef,
        ]);
      return;
    }
    foreach($result['values'] as $value){
      $message = $value['message'];
      $data = [
        'contact_id' => $message[$contact_id],
        'message' => $message,
      ];
      $this->queue->createItem(['process',$data]);
    }
  }

  /**
   * @param $data
   *
   * @return void
   */
  private function actionProcess($data){
    $create_user_plugin = $this->config->get('user_message_processor_plugin');
    $crt  = $this->userSyncManager->createInstance($create_user_plugin);
    $crt->process($data['contact_id'], $data['message'], $this->config);
  }

  /**
   * {@inheritdoc}
   */
  public function processItem($item) {
    try {
      [$action, $data] = $item;
      switch ($action) {
        case 'get' :
          $this->actionGet();
          break;
        case 'process' :
          $this->actionProcess($data);
          break;
        default:
      }
    } catch (\Exception $ex) {
      \Drupal::logger('cmrf_user_sync')
        ->error('Exception in @ex on processing @item ', [
          '@ex' => $ex->getMessage(),
          '@item' => $item,
        ]);
    }
  }

}
